# aind-sharepoint-service-async-client

## aind-sharepoint-service

Service to pull data from Sharepoint.



This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.5
- Package version: 0.1.5
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import aind_sharepoint_service_async_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import aind_sharepoint_service_async_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import aind_sharepoint_service_async_client
from aind_sharepoint_service_async_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = aind_sharepoint_service_async_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with aind_sharepoint_service_async_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aind_sharepoint_service_async_client.DefaultApi(api_client)
    subject_id = '805811' # str | 

    try:
        # Get Las 2020
        api_response = await api_instance.get_las2020(subject_id)
        print("The response of DefaultApi->get_las2020:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_las2020: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_las2020**](docs/DefaultApi.md#get_las2020) | **GET** /las_2020/{subject_id} | Get Las 2020
*DefaultApi* | [**get_nsb2019**](docs/DefaultApi.md#get_nsb2019) | **GET** /nsb_2019/{subject_id} | Get Nsb 2019
*DefaultApi* | [**get_nsb2023**](docs/DefaultApi.md#get_nsb2023) | **GET** /nsb_2023/{subject_id} | Get Nsb 2023
*DefaultApi* | [**get_nsb_present**](docs/DefaultApi.md#get_nsb_present) | **GET** /nsb_present/{subject_id} | Get Nsb Present
*HealthcheckApi* | [**get_health**](docs/HealthcheckApi.md#get_health) | **GET** /healthcheck | Perform a Health Check


## Documentation For Models

 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [LASBctype](docs/LASBctype.md)
 - [LASDeliverylocation](docs/LASDeliverylocation.md)
 - [LASDoseroute](docs/LASDoseroute.md)
 - [LASIcvlims](docs/LASIcvlims.md)
 - [LASIcvroute1](docs/LASIcvroute1.md)
 - [LASIcvroute2](docs/LASIcvroute2.md)
 - [LASIcvroute3](docs/LASIcvroute3.md)
 - [LASIcvroute4](docs/LASIcvroute4.md)
 - [LASIcvroute5](docs/LASIcvroute5.md)
 - [LASLimsproject](docs/LASLimsproject.md)
 - [LASLimsworkflow](docs/LASLimsworkflow.md)
 - [LASLimsworkflow2](docs/LASLimsworkflow2.md)
 - [LASPostfix](docs/LASPostfix.md)
 - [LASProjectid](docs/LASProjectid.md)
 - [LASProtocol](docs/LASProtocol.md)
 - [LASReqpro1](docs/LASReqpro1.md)
 - [LASReqpro2](docs/LASReqpro2.md)
 - [LASReqpro3](docs/LASReqpro3.md)
 - [LASReqpro4](docs/LASReqpro4.md)
 - [LASRequeststatus2](docs/LASRequeststatus2.md)
 - [LASRoeye1](docs/LASRoeye1.md)
 - [LASRoeye2](docs/LASRoeye2.md)
 - [LASRoeye3](docs/LASRoeye3.md)
 - [LASRoeye4](docs/LASRoeye4.md)
 - [LASRoeye5](docs/LASRoeye5.md)
 - [LASRolims](docs/LASRolims.md)
 - [LASRosop](docs/LASRosop.md)
 - [LASRowhere](docs/LASRowhere.md)
 - [LASSpecies](docs/LASSpecies.md)
 - [LASTamFrequency](docs/LASTamFrequency.md)
 - [LASTcprep](docs/LASTcprep.md)
 - [LASTctiss](docs/LASTctiss.md)
 - [LASTmpFrequency](docs/LASTmpFrequency.md)
 - [LASWheretoobtainsubstanceIcv](docs/LASWheretoobtainsubstanceIcv.md)
 - [Las2020List](docs/Las2020List.md)
 - [Lightcycle](docs/Lightcycle.md)
 - [NSB2019After1StInjection](docs/NSB2019After1StInjection.md)
 - [NSB2019After2NdInjection](docs/NSB2019After2NdInjection.md)
 - [NSB2019Contusion](docs/NSB2019Contusion.md)
 - [NSB2019CraniotomyType](docs/NSB2019CraniotomyType.md)
 - [NSB2019During1StInjection](docs/NSB2019During1StInjection.md)
 - [NSB2019During2NdInjection](docs/NSB2019During2NdInjection.md)
 - [NSB2019Durotomy](docs/NSB2019Durotomy.md)
 - [NSB2019EdemaSwelling](docs/NSB2019EdemaSwelling.md)
 - [NSB2019ExudateSeverity](docs/NSB2019ExudateSeverity.md)
 - [NSB2019EyeAffected](docs/NSB2019EyeAffected.md)
 - [NSB2019EyeIssue](docs/NSB2019EyeIssue.md)
 - [NSB2019FirstRoundInjIsoLevel](docs/NSB2019FirstRoundInjIsoLevel.md)
 - [NSB2019FirstRoundInjWorkstation](docs/NSB2019FirstRoundInjWorkstation.md)
 - [NSB2019Firstroundiontoissue](docs/NSB2019Firstroundiontoissue.md)
 - [NSB2019Firstroundiontonumber](docs/NSB2019Firstroundiontonumber.md)
 - [NSB2019Firstroundnanojectnumber](docs/NSB2019Firstroundnanojectnumber.md)
 - [NSB2019HeadpostType](docs/NSB2019HeadpostType.md)
 - [NSB2019Hematoma](docs/NSB2019Hematoma.md)
 - [NSB2019HpDurotomy](docs/NSB2019HpDurotomy.md)
 - [NSB2019HpIsoLevel](docs/NSB2019HpIsoLevel.md)
 - [NSB2019HpLocation](docs/NSB2019HpLocation.md)
 - [NSB2019HpPerferations](docs/NSB2019HpPerferations.md)
 - [NSB2019HpWorkStation](docs/NSB2019HpWorkStation.md)
 - [NSB2019IacucProtocol](docs/NSB2019IacucProtocol.md)
 - [NSB2019ImplantIdCoverslipType](docs/NSB2019ImplantIdCoverslipType.md)
 - [NSB2019Inj1Angle](docs/NSB2019Inj1Angle.md)
 - [NSB2019Inj1Hemisphere](docs/NSB2019Inj1Hemisphere.md)
 - [NSB2019Inj1Retsetting](docs/NSB2019Inj1Retsetting.md)
 - [NSB2019Inj1Round](docs/NSB2019Inj1Round.md)
 - [NSB2019Inj1Type](docs/NSB2019Inj1Type.md)
 - [NSB2019Inj2Angle](docs/NSB2019Inj2Angle.md)
 - [NSB2019Inj2Hemisphere](docs/NSB2019Inj2Hemisphere.md)
 - [NSB2019Inj2Retsetting](docs/NSB2019Inj2Retsetting.md)
 - [NSB2019Inj2Round](docs/NSB2019Inj2Round.md)
 - [NSB2019Inj2Type](docs/NSB2019Inj2Type.md)
 - [NSB2019Iontonumberhpinj](docs/NSB2019Iontonumberhpinj.md)
 - [NSB2019Issue](docs/NSB2019Issue.md)
 - [NSB2019Laceration](docs/NSB2019Laceration.md)
 - [NSB2019LightCycle](docs/NSB2019LightCycle.md)
 - [NSB2019LimsProjectCode](docs/NSB2019LimsProjectCode.md)
 - [NSB2019LimsRequired](docs/NSB2019LimsRequired.md)
 - [NSB2019Limstaskflow](docs/NSB2019Limstaskflow.md)
 - [NSB2019List](docs/NSB2019List.md)
 - [NSB2019PreviouslyInjected](docs/NSB2019PreviouslyInjected.md)
 - [NSB2019Procedure](docs/NSB2019Procedure.md)
 - [NSB2019ProjectId](docs/NSB2019ProjectId.md)
 - [NSB2019Scabbing](docs/NSB2019Scabbing.md)
 - [NSB2019SecondRoundInjIsoLevel](docs/NSB2019SecondRoundInjIsoLevel.md)
 - [NSB2019SecondRoundIontoIssue](docs/NSB2019SecondRoundIontoIssue.md)
 - [NSB2019SecondRoundWorkstation](docs/NSB2019SecondRoundWorkstation.md)
 - [NSB2019Secondroundiontonumber](docs/NSB2019Secondroundiontonumber.md)
 - [NSB2019Secondroundnanojectnumber](docs/NSB2019Secondroundnanojectnumber.md)
 - [NSB2019Sex](docs/NSB2019Sex.md)
 - [NSB2019SinusBleed](docs/NSB2019SinusBleed.md)
 - [NSB2019SurgeryStatus](docs/NSB2019SurgeryStatus.md)
 - [NSB2019TouchUpStatus](docs/NSB2019TouchUpStatus.md)
 - [NSB2019WindowClarity](docs/NSB2019WindowClarity.md)
 - [NSB2023AindProjectName](docs/NSB2023AindProjectName.md)
 - [NSB2023Behavior](docs/NSB2023Behavior.md)
 - [NSB2023BehaviorAutotrainCurriculum](docs/NSB2023BehaviorAutotrainCurriculum.md)
 - [NSB2023BehaviorCurriculumVersion](docs/NSB2023BehaviorCurriculumVersion.md)
 - [NSB2023BehaviorDestination](docs/NSB2023BehaviorDestination.md)
 - [NSB2023BehaviorFiberPhotometry](docs/NSB2023BehaviorFiberPhotometry.md)
 - [NSB2023BehaviorFipMode](docs/NSB2023BehaviorFipMode.md)
 - [NSB2023BehaviorFirstFipStage](docs/NSB2023BehaviorFirstFipStage.md)
 - [NSB2023BehaviorFirstVideoRecordingStage](docs/NSB2023BehaviorFirstVideoRecordingStage.md)
 - [NSB2023BehaviorPlatform](docs/NSB2023BehaviorPlatform.md)
 - [NSB2023BehaviorType](docs/NSB2023BehaviorType.md)
 - [NSB2023BlackCement](docs/NSB2023BlackCement.md)
 - [NSB2023Burr1FiberType](docs/NSB2023Burr1FiberType.md)
 - [NSB2023Burr1Hemisphere](docs/NSB2023Burr1Hemisphere.md)
 - [NSB2023Burr1InjectionDevice](docs/NSB2023Burr1InjectionDevice.md)
 - [NSB2023Burr1IntendedCcfTarget](docs/NSB2023Burr1IntendedCcfTarget.md)
 - [NSB2023Burr1IntendedMeasurementBlue](docs/NSB2023Burr1IntendedMeasurementBlue.md)
 - [NSB2023Burr1IntendedMeasurementGreen](docs/NSB2023Burr1IntendedMeasurementGreen.md)
 - [NSB2023Burr1IntendedMeasurementIsosbestic](docs/NSB2023Burr1IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr1IntendedMeasurementRed](docs/NSB2023Burr1IntendedMeasurementRed.md)
 - [NSB2023Burr1PerformDuring](docs/NSB2023Burr1PerformDuring.md)
 - [NSB2023Burr1SpinalLocation](docs/NSB2023Burr1SpinalLocation.md)
 - [NSB2023Burr1Status](docs/NSB2023Burr1Status.md)
 - [NSB2023Burr1VirusBiosafteyLevelBsl](docs/NSB2023Burr1VirusBiosafteyLevelBsl.md)
 - [NSB2023Burr2FiberType](docs/NSB2023Burr2FiberType.md)
 - [NSB2023Burr2Hemisphere](docs/NSB2023Burr2Hemisphere.md)
 - [NSB2023Burr2InjectionDevice](docs/NSB2023Burr2InjectionDevice.md)
 - [NSB2023Burr2IntendedCcfTarget](docs/NSB2023Burr2IntendedCcfTarget.md)
 - [NSB2023Burr2IntendedMeasurementBlue](docs/NSB2023Burr2IntendedMeasurementBlue.md)
 - [NSB2023Burr2IntendedMeasurementGreen](docs/NSB2023Burr2IntendedMeasurementGreen.md)
 - [NSB2023Burr2IntendedMeasurementIsosbestic](docs/NSB2023Burr2IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr2IntendedMeasurementRed](docs/NSB2023Burr2IntendedMeasurementRed.md)
 - [NSB2023Burr2PerformDuring](docs/NSB2023Burr2PerformDuring.md)
 - [NSB2023Burr2SpinalLocation](docs/NSB2023Burr2SpinalLocation.md)
 - [NSB2023Burr2Status](docs/NSB2023Burr2Status.md)
 - [NSB2023Burr2VirusBiosafteyLevelBsl](docs/NSB2023Burr2VirusBiosafteyLevelBsl.md)
 - [NSB2023Burr3FiberType](docs/NSB2023Burr3FiberType.md)
 - [NSB2023Burr3Hemisphere](docs/NSB2023Burr3Hemisphere.md)
 - [NSB2023Burr3InjectionDevice](docs/NSB2023Burr3InjectionDevice.md)
 - [NSB2023Burr3IntendedCcfTarget](docs/NSB2023Burr3IntendedCcfTarget.md)
 - [NSB2023Burr3IntendedMeasurementBlue](docs/NSB2023Burr3IntendedMeasurementBlue.md)
 - [NSB2023Burr3IntendedMeasurementGreen](docs/NSB2023Burr3IntendedMeasurementGreen.md)
 - [NSB2023Burr3IntendedMeasurementIsosbestic](docs/NSB2023Burr3IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr3IntendedMeasurementRed](docs/NSB2023Burr3IntendedMeasurementRed.md)
 - [NSB2023Burr3PerformDuring](docs/NSB2023Burr3PerformDuring.md)
 - [NSB2023Burr3Status](docs/NSB2023Burr3Status.md)
 - [NSB2023Burr3VirusBiosafetyLevelBsl](docs/NSB2023Burr3VirusBiosafetyLevelBsl.md)
 - [NSB2023Burr4FiberType](docs/NSB2023Burr4FiberType.md)
 - [NSB2023Burr4Hemisphere](docs/NSB2023Burr4Hemisphere.md)
 - [NSB2023Burr4InjectionDevice](docs/NSB2023Burr4InjectionDevice.md)
 - [NSB2023Burr4IntendedCcfTarget](docs/NSB2023Burr4IntendedCcfTarget.md)
 - [NSB2023Burr4IntendedMeasurementBlue](docs/NSB2023Burr4IntendedMeasurementBlue.md)
 - [NSB2023Burr4IntendedMeasurementGreen](docs/NSB2023Burr4IntendedMeasurementGreen.md)
 - [NSB2023Burr4IntendedMeasurementIsosbestic](docs/NSB2023Burr4IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr4IntendedMeasurementRed](docs/NSB2023Burr4IntendedMeasurementRed.md)
 - [NSB2023Burr4PerformDuring](docs/NSB2023Burr4PerformDuring.md)
 - [NSB2023Burr4Status](docs/NSB2023Burr4Status.md)
 - [NSB2023Burr4VirusBiosafteyLevelBsl](docs/NSB2023Burr4VirusBiosafteyLevelBsl.md)
 - [NSB2023Burr5FiberType](docs/NSB2023Burr5FiberType.md)
 - [NSB2023Burr5Hemisphere](docs/NSB2023Burr5Hemisphere.md)
 - [NSB2023Burr5InjectionDevice](docs/NSB2023Burr5InjectionDevice.md)
 - [NSB2023Burr5IntendedCcfTarget](docs/NSB2023Burr5IntendedCcfTarget.md)
 - [NSB2023Burr5IntendedMeasurementBlue](docs/NSB2023Burr5IntendedMeasurementBlue.md)
 - [NSB2023Burr5IntendedMeasurementGreen](docs/NSB2023Burr5IntendedMeasurementGreen.md)
 - [NSB2023Burr5IntendedMeasurementIsosbestic](docs/NSB2023Burr5IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr5IntendedMeasurementRed](docs/NSB2023Burr5IntendedMeasurementRed.md)
 - [NSB2023Burr5PerformDuring](docs/NSB2023Burr5PerformDuring.md)
 - [NSB2023Burr5Status](docs/NSB2023Burr5Status.md)
 - [NSB2023Burr5VirusBiosafteyLevelBsl](docs/NSB2023Burr5VirusBiosafteyLevelBsl.md)
 - [NSB2023Burr6FiberType](docs/NSB2023Burr6FiberType.md)
 - [NSB2023Burr6Hemisphere](docs/NSB2023Burr6Hemisphere.md)
 - [NSB2023Burr6InjectionDevice](docs/NSB2023Burr6InjectionDevice.md)
 - [NSB2023Burr6IntendedCcfTarget](docs/NSB2023Burr6IntendedCcfTarget.md)
 - [NSB2023Burr6IntendedMeasurementBlue](docs/NSB2023Burr6IntendedMeasurementBlue.md)
 - [NSB2023Burr6IntendedMeasurementGreen](docs/NSB2023Burr6IntendedMeasurementGreen.md)
 - [NSB2023Burr6IntendedMeasurementIsosbestic](docs/NSB2023Burr6IntendedMeasurementIsosbestic.md)
 - [NSB2023Burr6IntendedMeasurementRed](docs/NSB2023Burr6IntendedMeasurementRed.md)
 - [NSB2023Burr6PerformDuring](docs/NSB2023Burr6PerformDuring.md)
 - [NSB2023Burr6Status](docs/NSB2023Burr6Status.md)
 - [NSB2023Burr6VirusBiosafteyLevelBsl](docs/NSB2023Burr6VirusBiosafteyLevelBsl.md)
 - [NSB2023BurrHole1](docs/NSB2023BurrHole1.md)
 - [NSB2023BurrHole2](docs/NSB2023BurrHole2.md)
 - [NSB2023BurrHole3](docs/NSB2023BurrHole3.md)
 - [NSB2023BurrHole4](docs/NSB2023BurrHole4.md)
 - [NSB2023BurrHole5](docs/NSB2023BurrHole5.md)
 - [NSB2023BurrHole6](docs/NSB2023BurrHole6.md)
 - [NSB2023CareModuele](docs/NSB2023CareModuele.md)
 - [NSB2023ContusionHematoma](docs/NSB2023ContusionHematoma.md)
 - [NSB2023CraniotomyPerformDuring](docs/NSB2023CraniotomyPerformDuring.md)
 - [NSB2023CraniotomyType](docs/NSB2023CraniotomyType.md)
 - [NSB2023EdemaSwelling](docs/NSB2023EdemaSwelling.md)
 - [NSB2023FiberImplant1Length](docs/NSB2023FiberImplant1Length.md)
 - [NSB2023FiberImplant2Length](docs/NSB2023FiberImplant2Length.md)
 - [NSB2023FiberImplant3Length](docs/NSB2023FiberImplant3Length.md)
 - [NSB2023FiberImplant4Length](docs/NSB2023FiberImplant4Length.md)
 - [NSB2023FiberImplant5Length](docs/NSB2023FiberImplant5Length.md)
 - [NSB2023FiberImplant6Length](docs/NSB2023FiberImplant6Length.md)
 - [NSB2023FollowUpNanojectNumber](docs/NSB2023FollowUpNanojectNumber.md)
 - [NSB2023FollowUpWorkstation](docs/NSB2023FollowUpWorkstation.md)
 - [NSB2023FolowUpIontoNumber](docs/NSB2023FolowUpIontoNumber.md)
 - [NSB2023Headpost](docs/NSB2023Headpost.md)
 - [NSB2023HeadpostPerformDuring](docs/NSB2023HeadpostPerformDuring.md)
 - [NSB2023IacucProtocol](docs/NSB2023IacucProtocol.md)
 - [NSB2023ImplantIdCoverslipType](docs/NSB2023ImplantIdCoverslipType.md)
 - [NSB2023InitialIontoNumber](docs/NSB2023InitialIontoNumber.md)
 - [NSB2023InitialNanojectNumber](docs/NSB2023InitialNanojectNumber.md)
 - [NSB2023InitialWorkStation](docs/NSB2023InitialWorkStation.md)
 - [NSB2023Inj1Retsetting](docs/NSB2023Inj1Retsetting.md)
 - [NSB2023Inj1Type](docs/NSB2023Inj1Type.md)
 - [NSB2023Inj2Retsetting](docs/NSB2023Inj2Retsetting.md)
 - [NSB2023Inj2Type](docs/NSB2023Inj2Type.md)
 - [NSB2023Inj3Retsetting](docs/NSB2023Inj3Retsetting.md)
 - [NSB2023Inj3Type](docs/NSB2023Inj3Type.md)
 - [NSB2023Inj4Retsetting](docs/NSB2023Inj4Retsetting.md)
 - [NSB2023Inj4Type](docs/NSB2023Inj4Type.md)
 - [NSB2023Inj5Retsetting](docs/NSB2023Inj5Retsetting.md)
 - [NSB2023Inj5Type](docs/NSB2023Inj5Type.md)
 - [NSB2023Inj6Retsetting](docs/NSB2023Inj6Retsetting.md)
 - [NSB2023Inj6Type](docs/NSB2023Inj6Type.md)
 - [NSB2023Laceration](docs/NSB2023Laceration.md)
 - [NSB2023LimsProject](docs/NSB2023LimsProject.md)
 - [NSB2023LimsRequired](docs/NSB2023LimsRequired.md)
 - [NSB2023LimsTaskflow](docs/NSB2023LimsTaskflow.md)
 - [NSB2023List](docs/NSB2023List.md)
 - [NSB2023OfBurrHoles](docs/NSB2023OfBurrHoles.md)
 - [NSB2023PhysiologyType](docs/NSB2023PhysiologyType.md)
 - [NSB2023Procedure](docs/NSB2023Procedure.md)
 - [NSB2023ProcedureCategory](docs/NSB2023ProcedureCategory.md)
 - [NSB2023ProcedureSlots](docs/NSB2023ProcedureSlots.md)
 - [NSB2023ProjectId](docs/NSB2023ProjectId.md)
 - [NSB2023Protocol](docs/NSB2023Protocol.md)
 - [NSB2023Sex](docs/NSB2023Sex.md)
 - [NSB2023SinusBleed](docs/NSB2023SinusBleed.md)
 - [NSB2023SurgeryStatus](docs/NSB2023SurgeryStatus.md)
 - [NSB2023Thermistor](docs/NSB2023Thermistor.md)
 - [NSB2023Well](docs/NSB2023Well.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




